@@ -6,7 +6,8 @@ from ..utils.compatibility import PILExifTags, PILImage
 def get_exif(im):
     try:
         exif_raw = im._getexif() or {}
-    except:  # noqa
+    except Exception:
+        # Not available? Return empty dict
         return {}
     ret = {}
     for tag, value in list(exif_raw.items()):
@@ -23,6 +24,6 @@ def get_exif_for_file(file_obj):
 def get_subject_location(exif_data):
     try:
         r = (int(exif_data['SubjectLocation'][0]), int(exif_data['SubjectLocation'][1]),)
-    except:  # noqa
+    except KeyError:
         r = None
     return r
